@@ -14,7 +14,7 @@
 # ==============================================================================
 """Collection of first-party plugins.
 
-This module exists to isolate tensorboard.server from the potentially
+This module exists to isolate tensorboard.program from the potentially
 heavyweight build dependencies for first-party plugins. This way people
 doing custom builds of TensorBoard have the option to only pay for the
 dependencies they want.
@@ -28,11 +28,14 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import logging
 import os
 
 import tensorflow as tf
 
+from tensorboard.plugins import base_plugin
 from tensorboard.plugins.audio import audio_plugin
+from tensorboard.plugins.beholder import beholder_plugin
 from tensorboard.plugins.core import core_plugin
 from tensorboard.plugins.custom_scalar import custom_scalars_plugin
 from tensorboard.plugins.distribution import distributions_plugin
@@ -46,34 +49,24 @@ from tensorboard.plugins.projector import projector_plugin
 from tensorboard.plugins.scalar import scalars_plugin
 from tensorboard.plugins.text import text_plugin
 
+logger = logging.getLogger(__name__)
 
-def get_plugins():
-  """Returns list of TensorBoard's first-party TBPlugin classes.
-
-  This list can then be passed to functions in `tensorboard.server` or
-  `tensorboard.backend.application`.
-
-  :rtype: list[:class:`base_plugin.TBPlugin`]
-  """
-  plugins = [
-      core_plugin.CorePlugin,
-      scalars_plugin.ScalarsPlugin,
-      custom_scalars_plugin.CustomScalarsPlugin,
-      images_plugin.ImagesPlugin,
-      audio_plugin.AudioPlugin,
-      graphs_plugin.GraphsPlugin,
-      distributions_plugin.DistributionsPlugin,
-      histograms_plugin.HistogramsPlugin,
-      pr_curves_plugin.PrCurvesPlugin,
-      projector_plugin.ProjectorPlugin,
-      text_plugin.TextPlugin,
-      profile_plugin.ProfilePlugin,
-  ]
-  # The debugger plugin is only activated if its flag is set.
-  debugger = debugger_plugin_loader.get_debugger_plugin()
-  if debugger is not None:
-    plugins.append(debugger)
-  return plugins
+PLUGIN_LOADERS = [
+    core_plugin.CorePluginLoader(),
+    base_plugin.BasicLoader(beholder_plugin.BeholderPlugin),
+    base_plugin.BasicLoader(scalars_plugin.ScalarsPlugin),
+    base_plugin.BasicLoader(custom_scalars_plugin.CustomScalarsPlugin),
+    base_plugin.BasicLoader(images_plugin.ImagesPlugin),
+    base_plugin.BasicLoader(audio_plugin.AudioPlugin),
+    base_plugin.BasicLoader(graphs_plugin.GraphsPlugin),
+    base_plugin.BasicLoader(distributions_plugin.DistributionsPlugin),
+    base_plugin.BasicLoader(histograms_plugin.HistogramsPlugin),
+    base_plugin.BasicLoader(pr_curves_plugin.PrCurvesPlugin),
+    base_plugin.BasicLoader(projector_plugin.ProjectorPlugin),
+    base_plugin.BasicLoader(text_plugin.TextPlugin),
+    profile_plugin.ProfilePluginLoader(),
+    debugger_plugin_loader.DebuggerPluginLoader(),
+]
 
 
 def get_assets_zip_provider():
@@ -87,6 +80,6 @@ def get_assets_zip_provider():
   """
   path = os.path.join(tf.resource_loader.get_data_files_path(), 'webfiles.zip')
   if not os.path.exists(path):
-    tf.logging.warning('webfiles.zip static assets not found: %s', path)
+    logger.warning('webfiles.zip static assets not found: %s', path)
     return None
   return lambda: open(path, 'rb')
